powered by
Specifies the information required to fit a Negative Binomial generalized linear model, with known theta parameter, using glm().
theta
glm()
negative.binomial(theta = stop("'theta' must be specified"), link = "log")
An object of class "family", a list of functions and expressions needed by glm() to fit a Negative Binomial generalized linear model.
"family"
Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S-PLUS. Fourth Edition. Springer.
glm.nb, anova.negbin, summary.negbin
glm.nb
anova.negbin
summary.negbin
# Fitting a Negative Binomial model to the quine data # with theta = 2 assumed known. # glm(Days ~ .^4, family = negative.binomial(2), data = quine)
Run the code above in your browser using DataLab