Fit a regression to the good points in the dataset, thereby
achieving a regression estimator with a high breakdown point.
lmsreg and ltsreg are compatibility wrappers.
lqs(x, ...)# S3 method for formula
lqs(formula, data, ...,
method = c("lts", "lqs", "lms", "S", "model.frame"),
subset, na.action, model = TRUE,
x.ret = FALSE, y.ret = FALSE, contrasts = NULL)
# S3 method for default
lqs(x, y, intercept = TRUE, method = c("lts", "lqs", "lms", "S"),
quantile, control = lqs.control(...), k0 = 1.548, seed, ...)
lmsreg(...)
ltsreg(...)
An object of class "lqs". This is a list with components
the value of the criterion for the best solution found, in
the case of method == "S" before IWLS refinement.
character. A message about the number of samples which resulted in singular fits.
of the fitted linear model
the indices of those points fitted by the best sample found (prior to adjustment of the intercept, if requested).
the fitted values.
the residuals.
estimate(s) of the scale of the error. The first is based
on the fit criterion. The second (not present for method ==
"S") is based on the variance of those residuals whose absolute
value is less than 2.5 times the initial estimate.
Suppose there are n data points and p regressors,
including any intercept.
The first three methods minimize some function of the sorted squared
residuals. For methods "lqs" and "lms" is the
quantile squared residual, and for "lts" it is the sum
of the quantile smallest squared residuals. "lqs" and
"lms" differ in the defaults for quantile, which are
floor((n+p+1)/2) and floor((n+1)/2) respectively.
For "lts" the default is floor(n/2) + floor((p+1)/2).
The "S" estimation method solves for the scale s
such that the average of a function chi of the residuals divided
by s is equal to a given constant.
The control argument is a list with components
psamp:the size of each sample. Defaults to p.
nsamp:the number of samples or "best" (the
default) or "exact" or "sample".
If "sample" the number chosen is min(5*p, 3000),
taken from Rousseeuw and Hubert (1997).
If "best" exhaustive enumeration is done up to 5000 samples;
if "exact" exhaustive enumeration will be attempted however
many samples are needed.
adjust:should the intercept be optimized for each
sample? Defaults to TRUE.
P. J. Rousseeuw and A. M. Leroy (1987) Robust Regression and Outlier Detection. Wiley.
A. Marazzi (1993) Algorithms, Routines and S Functions for Robust Statistics. Wadsworth and Brooks/Cole.
P. Rousseeuw and M. Hubert (1997) Recent developments in PROGRESS. In L1-Statistical Procedures and Related Topics, ed Y. Dodge, IMS Lecture Notes volume 31, pp. 201--214.
predict.lqs
## IGNORE_RDIFF_BEGIN
set.seed(123) # make reproducible
lqs(stack.loss ~ ., data = stackloss)
lqs(stack.loss ~ ., data = stackloss, method = "S", nsamp = "exact")
## IGNORE_RDIFF_END
Run the code above in your browser using DataLab