Plots a set of data on one, two or more linear discriminants.
# S3 method for lda
plot(x, panel = panel.lda, ..., cex = 0.7, dimen,
abbrev = FALSE, xlab = "LD1", ylab = "LD2")This function is a method for the generic function
plot() for class "lda".
It can be invoked by calling plot(x) for an
object x of the appropriate class, or directly by
calling plot.lda(x) regardless of the
class of the object.
The behaviour is determined by the value of dimen. For
dimen > 2, a pairs plot is used. For dimen = 2, an
equiscaled scatter plot is drawn. For dimen = 1, a set of
histograms or density plots are drawn. Use argument type to
match "histogram" or "density" or "both".
Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S. Fourth edition. Springer.
pairs.lda, ldahist, lda, predict.lda